@@ -6,9 +6,9 @@ parent_dir = os.path.dirname(os.path.abspath(__file__))
 css_file = os.path.join(parent_dir, "style.css")
 
 
-def st_menu(menu_items={}, header={}, divider_between_header_and_body=True, header_style={}, wrapper_style={}, submenu_style={}, single_menu_style={}, is_collapsible=False, on_change=None, args=None):
+def st_menu(menu_items={}, header={}, divider_between_header_and_body=True, header_style={}, wrapper_style={}, submenu_style={}, single_menu_style={}, is_collapsible=False, on_menu_select=None, args=None):
     with st.sidebar:
-        getMenu(menu_items=menu_items,
+        selected_maneu = getMenu(menu_items=menu_items,
                 header=header,
                 divider_between_header_and_body=divider_between_header_and_body,
                 header_style=header_style,
@@ -17,7 +17,7 @@ def st_menu(menu_items={}, header={}, divider_between_header_and_body=True, head
                 single_menu_style=single_menu_style,
                 is_collapsible=is_collapsible,
                 key="sidemenu",
-                on_select=on_change,
+                on_select=on_menu_select,
                 args=args)
 
-    return st.session_state["sidemenu"]
+    return selected_maneu["title"]
