@@ -79,4 +79,4 @@ def getMenu(header={},
     set_component_rerender_count(key)
     # We could modify the value returned from the component if we wanted.
     # There's no need to do this in our simple example - but it's an option.
-    return component_value["title"]
+    return component_value
